from distutils.core import setup

setup(
    name="folio_uuid",
    packages=["folio_uuid"],
    version="0.1.0",
    license="MIT",
    long_description="",
    description="A library for generating predictive uuids for FOLIO data migrations",
    author="Theodor Tolstoy",
    author_email="pypi.teddes@tolstoy.se",
    url="https://github.com/FOLIO-FSE/folio_uuid",
    download_url="https://github.com/FOLIO-FSE/folio_uuid/archive/v_01.tar.gz",
    keywords=["FOLIO", "FOLIO_LSP", "OKAPI", "API Wrapper", "UUID"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
)
